#
# spec file for package nip2
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           nip2
Version:        8.6.0
Release:        lp151.2.67
Summary:        Interactive tool for working with large images
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Other
Url:            http://www.vips.ecs.soton.ac.uk/
Source0:        https://github.com/jcupitt/nip2/releases/download/v8.6.0/nip2-8.6.0.tar.gz
# Fix broken PNG file: https://github.com/jcupitt/nip2/commit/7bc6212cb51d266f1a6fc3e05260390af4d80c99
Source2:        simp_base.png
# PATCH-FIX-OPENSUSE nip2-doc-path.patch
Patch1:         nip2-doc-path.patch
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  fftw3-devel
BuildRequires:  flex
BuildRequires:  goffice-0_8-devel
BuildRequires:  graphviz-devel
BuildRequires:  gsl-devel
BuildRequires:  gtk2-devel
BuildRequires:  libgsf-devel
BuildRequires:  libvips-devel
BuildRequires:  libxml2-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
nip2 is a user interface for the VIPS image processing library.
VIPS library is good with large images (images larger than the amount
of RAM you have available), with many CPUs, for working with colour,
for scientific analysis and for general research & development.

%prep
%setup -q
%patch1 -p1
# Fix broken PNG file
cp %{SOURCE2} share/nip2/data/examples/manual_balance/simp_base.png

%build
%configure
make %{?_smp_mflags}

%install
%make_install
install -D share/nip2/data/vips-128.png %{buildroot}%{_datadir}/pixmaps/%{name}.png
rm -rf %{buildroot}%{_datadir}/doc/nip2
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}

%check
make check

%files -f %{name}.lang
%defattr(-,root,root)
%doc doc/html doc/pdf AUTHORS ChangeLog COPYING NEWS THANKS
%{_bindir}/*
%{_datadir}/%{name}/
%{_mandir}/man1/nip2.1.gz
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/mime/packages/nip2.xml
%dir %{_datadir}/appdata
%{_datadir}/appdata/%{name}.appdata.xml

%changelog
* Sun Apr  8 2018 plinnell@opensuse.org
- Fix Source URL to make OBS happy
* Tue Mar 27 2018 guillaume.gardet@opensuse.org
- Update to 8.6.0
- Fix broken PNG file which breaks 'make check'
* Sun Jan  8 2017 dmitry_r@opensuse.org
- Update to version 8.4
  * added Perlin and Worley menu items
  * improve middle-drag in ws and image view
  * be more careful about the name of the image file we remove on close
  * simpler system for positioning new columns
  * move path search stuff into _convert from _magick
  * added autotrace menu item
  * resize now uses vips_resize() behind the scenes
  * added Kernel type for picking interpolators
  * added R2 to linreg and linregw
  * changed default unsharp settings to be less brutal and to ban -ve sharpness
  * fix icc_import with RGBA images
  * added mapim and Image / Transform / Map
  * added Filter / Coordinate Transform ... polar and rect in there
* Wed May  6 2015 dmitry_r@opensuse.org
- Update to version 8.0
  * Version bump for vips-8.0 release
- Enable tests on 64-bit platforms
* Mon Jan 12 2015 dmitry_r@opensuse.org
- Update to version 7.42.1
  * See included ChangeLog file for details
* Wed Oct 22 2014 dmitry_r@opensuse.org
- Update to version 7.40.4
  * swap the HP printer profile for a freer one
  * swap lena for a PD sample
* Tue Jul 29 2014 dmitry_r@opensuse.org
- Update to version 7.40.3
  * fix compile with older libvipes, now goes back to at least 7.30
  * don't test IM by default, in case it's not installed
  * get graph display working again with latest libgvc
  * fix quoting in magick commands
  * auto-fallback to gm if no convert found
  * use libxml2 pretty-printer
* Fri Jun 27 2014 dmitry_r@opensuse.org
- Update to version 7.40.1
  * larger max size for dialog text
* Tue Jun 24 2014 dmitry_r@opensuse.org
- Update to version 7.40.0
  * added export-to-file to plotwindow
  * added graph_export_image
  * added .to_image to Plot
  * added .caption / .xcaption / .ycaption options to Plot
  * added caption / xcaption / ycaption options to Plot_object
  * added snibgo's much better ImageMagick menu items
  * added series_captions option to Plot_object
  * support imagevec as a vips_call argument
  * added system2 and system3
  * added Magick.version detector
  * better image cache menu item
  * added hough_line and hough_circle
  * removed tear-off menus, gtk+ has deprecated them
* Tue Jan 21 2014 dmitry_r@opensuse.org
- Update to version 7.38.1
  * add scRGB to list of known Types
  * fix scRGB display
* Sun Jan 19 2014 dmitry_r@opensuse.org
- Update to version 7.38.0
  * version bump due to new release of vips library
* Fri Dec 20 2013 dmitry_r@opensuse.org
- Update to version 7.36.5
  * add "merge into ws" item to rmb tab gutter menu
  * fix progress feedback
  * error boxes were accidentally supressed
* Thu Nov 14 2013 dmitry_r@opensuse.org
- Update to version 7.36.4
  * fix bootstrap warnings
  * use g_mkdir()
  * better load of workspaces with closed columns
* Thu Oct 17 2013 dmitry_r@opensuse.org
- Update to version 7.36.2
  * add --profile option
  * fix + button on wsgv
* Tue Oct  8 2013 dmitry_r@opensuse.org
- Update to version 7.36.1
  * better ^Q behaviour
* Sat Oct  5 2013 dmitry_r@opensuse.org
- Update to version 7.36.0
  * removed old thing to show API docs
  * measure now lets you pick the area to measure, and draws sample patches
  * new column now goes to right of current column, not alphabetically
  * detect doubleclick on ws tab label background
  * tabs can be locked
  * tabs have error indicators
* Thu Jul  4 2013 dmitry_r@opensuse.org
- Update to version 7.34.1
  * drag col to far left to insert
  * fix compat warning text
  * fix prefs revert to default
  * reenable scroll-wheel slider change in paintbox and conversionview
  * insert new columns in alphabetical position
* Sat Jun 15 2013 dmitry_r@opensuse.org
- Update to version 7.32.1
  * remove "fred" from dist
* Wed Mar  6 2013 dmitry_r@opensuse.org
- Update to version 7.32.0
  * added colour temperature to colour and colour to colour temperature
  * removed gtksheet, broken on windows, no future on anywhere
  * added histogram invert
  * much better Matrix / New items
  * removed obsolete nip2-gcc-warnings.patch
* Sat Jan 19 2013 dmitry_r@opensuse.org
- Update to version 7.30.2
  * Small bugfixes
  * Removed obsolete nip2-flex-build.patch
* Fri Oct 26 2012 dmitry_r@opensuse.org
- Fix build with flex >= 2.5.36
  * nip2-flex-build.patch
* Mon Sep 17 2012 cfarrell@suse.com
- license update: GPL-2.0+
  No GPL-2.0 "only" licenses found in package. Fedora also denote this
  package as GPL-2.0+
* Tue Sep 11 2012 dmitry_r@opensuse.org
- Initial package
- Version 7.30.1
